// define if you want to use exception handling
#undef USE_EXCEPTION

// define if you want verbose exception handling
#undef VERBOSE_EXCEPTION

// define if you have the ISO C++ friend declaration style
#undef HAVE_ISO_FRIEND_DECL

// define if you can handle the template of template class
#undef HAVE_TEMPLATE_OF_TEMPLATE

// define if you can use -fno-implicit-template
#undef NO_IMPLICIT_TEMPLATES

// define if you can use -frepo
#undef INCLUDE_TEMPLATE_SOURCE

// define if you want Image Magick 
#undef WITH_IMAGE_MAGICK

// define if you want to do range validity checking
// and also other debugging functions
#undef DEBUG_PLIB

// Define if you want the matrix to be in column order rather than row order.
// Column ordering is used by fortran and OpenGL.
#undef COLUMN_ORDER

// the name of the package
#undef PACKAGE 

// the version of the package
#undef VERSION 

// if the C++ compiler supports namespaces
#undef HAVE_NAMESPACE

// Specify if OpenGL is present on this system
#undef WITH_OPENGL 

// Specify if you are using Solaris with egcs
#undef USING_GNU_SOLARIS

// Specify if you are using DEC Alpha with egcs
#undef USING_GNU_DECALPHA

// Specify if you are using SGI with egcs
#undef USING_GNU_SGI

// Specify if you are using Linux (assumed with egcs)
#undef USING_LINUX

// Specify if you have CppUnit installed
#undef HAS_CPPUNIT

// Specify if you have abs defined for the Complex type
#undef HAS_COMPLEX_ABS

// Specify if you have conf defined for the Complex type
#undef HAS_COMPLEX_CONJ
